<?php

namespace Shopping\Customized\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Shopping\Customized\Interfaces\CustomizedRepositoryInterface;

class CustomizedPublicController extends BaseController
{
    // use CustomizedWorkflow;

    /**
     * Constructor.
     *
     * @param type \Shopping\Customized\Interfaces\CustomizedRepositoryInterface $customized
     *
     * @return type
     */
    public function __construct(CustomizedRepositoryInterface $customized)
    {
        $this->repository = $customized;
        parent::__construct();
    }

    /**
     * Show customized's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $customizeds = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$customized::$customized.names'))
            ->view('$customized::public.customized.index')
            ->data(compact('$customizeds'))
            ->output();
    }

    /**
     * Show customized's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $customizeds = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$customized::$customized.names'))
            ->view('$customized::public.customized.index')
            ->data(compact('$customizeds'))
            ->output();
    }

    /**
     * Show customized.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $customized = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$customized->name . trans('$customized::$customized.name'))
            ->view('$customized::public.customized.show')
            ->data(compact('$customized'))
            ->output();
    }

}
