<?php

namespace Shopping\Customized\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Customized\Models\Attributes;

class AttributesPolicy
{

    /**
     * Determine if the given user can view the attributes.
     *
     * @param UserPolicy $user
     * @param Attributes $attributes
     *
     * @return bool
     */
    public function view(UserPolicy $user, Attributes $attributes)
    {
        if ($user->canDo('customized.attributes.view') && $user->isAdmin()) {
            return true;
        }

        return $attributes->user_id == user_id() && $attributes->user_type == user_type();
    }

    /**
     * Determine if the given user can create a attributes.
     *
     * @param UserPolicy $user
     * @param Attributes $attributes
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('customized.attributes.create');
    }

    /**
     * Determine if the given user can update the given attributes.
     *
     * @param UserPolicy $user
     * @param Attributes $attributes
     *
     * @return bool
     */
    public function update(UserPolicy $user, Attributes $attributes)
    {
        if ($user->canDo('customized.attributes.edit') && $user->isAdmin()) {
            return true;
        }

        return $attributes->user_id == user_id() && $attributes->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given attributes.
     *
     * @param UserPolicy $user
     * @param Attributes $attributes
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Attributes $attributes)
    {
        return $attributes->user_id == user_id() && $attributes->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given attributes.
     *
     * @param UserPolicy $user
     * @param Attributes $attributes
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Attributes $attributes)
    {
        if ($user->canDo('customized.attributes.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given attributes.
     *
     * @param UserPolicy $user
     * @param Attributes $attributes
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Attributes $attributes)
    {
        if ($user->canDo('customized.attributes.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
