<?php

namespace Shopping\Customized\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Customized\Models\Customized;

class CustomizedPolicy
{

    /**
     * Determine if the given user can view the customized.
     *
     * @param UserPolicy $user
     * @param Customized $customized
     *
     * @return bool
     */
    public function view(UserPolicy $user, Customized $customized)
    {
        if ($user->canDo('customized.customized.view') && $user->isAdmin()) {
            return true;
        }

        return $customized->user_id == user_id() && $customized->user_type == user_type();
    }

    /**
     * Determine if the given user can create a customized.
     *
     * @param UserPolicy $user
     * @param Customized $customized
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('customized.customized.create');
    }

    /**
     * Determine if the given user can update the given customized.
     *
     * @param UserPolicy $user
     * @param Customized $customized
     *
     * @return bool
     */
    public function update(UserPolicy $user, Customized $customized)
    {
        if ($user->canDo('customized.customized.edit') && $user->isAdmin()) {
            return true;
        }

        return $customized->user_id == user_id() && $customized->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given customized.
     *
     * @param UserPolicy $user
     * @param Customized $customized
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Customized $customized)
    {
        return $customized->user_id == user_id() && $customized->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given customized.
     *
     * @param UserPolicy $user
     * @param Customized $customized
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Customized $customized)
    {
        if ($user->canDo('customized.customized.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given customized.
     *
     * @param UserPolicy $user
     * @param Customized $customized
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Customized $customized)
    {
        if ($user->canDo('customized.customized.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
