<?php

namespace Shopping\Customized\Providers;

use Illuminate\Support\ServiceProvider;

class CustomizedServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'customized');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'customized');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('shopping.customized', function ($app) {
            return $this->app->make('Shopping\Customized\Customized');
        });

        // Bind Customized to repository
        $this->app->bind(
            'Shopping\Customized\Interfaces\CustomizedRepositoryInterface',
            \Shopping\Customized\Repositories\Eloquent\CustomizedRepository::class
        );
        // Bind Group to repository
        $this->app->bind(
            'Shopping\Customized\Interfaces\GroupRepositoryInterface',
            \Shopping\Customized\Repositories\Eloquent\GroupRepository::class
        );
        // Bind Attributes to repository
        $this->app->bind(
            'Shopping\Customized\Interfaces\AttributesRepositoryInterface',
            \Shopping\Customized\Repositories\Eloquent\AttributesRepository::class
        );

        $this->app->register(\Shopping\Customized\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Shopping\Customized\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['shopping.customized'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('shopping/customized.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/customized')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/customized')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
