<?php

namespace Shopping\Customized\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Shopping\Customized\Models\Customized;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Shopping\Customized\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/customized/customized/*')) {
            Route::bind('customized', function ($customized) {
                $customizedrepo = $this->app->make('Shopping\Customized\Interfaces\CustomizedRepositoryInterface');
                return $customizedrepo->findorNew($customized);
            });
        }

        if (Request::is('*/customized/group/*')) {
            Route::bind('group', function ($group) {
                $grouprepo = $this->app->make('Shopping\Customized\Interfaces\GroupRepositoryInterface');
                return $grouprepo->findorNew($group);
            });
        }

        if (Request::is('*/customized/attributes/*')) {
            Route::bind('attributes', function ($attributes) {
                $attributesrepo = $this->app->make('Shopping\Customized\Interfaces\AttributesRepositoryInterface');
                return $attributesrepo->findorNew($attributes);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        if(request()->segment(1) != 'api' && request()->segment(2) != 'api') {
            return;
        }

        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
